@@ -55,6 +55,7 @@
 #pragma once
 
 #include <cstdint>
+#include <sstream>
 #include <string>
 #include <iomanip>
 
@@ -68,17 +69,23 @@ namespace pdal
 
 #pragma pack(push)
 #pragma pack(1)
-struct uuid
+struct PDAL_DLL uuid
 {
+    uuid()
+    { clear(); }
+
     uint32_t time_low;
     uint16_t time_mid;
     uint16_t time_hi_and_version;
     uint16_t clock_seq;
     uint8_t node[6];
+
+    void clear()
+    { memset(this, 0, sizeof(struct uuid)); }
 };
 #pragma pack(pop)
 
-inline bool operator < (const uuid& u1, const uuid& u2)
+PDAL_DLL inline bool operator < (const uuid& u1, const uuid& u2)
 {
     if (u1.time_low != u2.time_low)
         return u1.time_low < u2.time_low;
@@ -94,18 +101,17 @@ inline bool operator < (const uuid& u1, const uuid& u2)
 
 class PDAL_DLL Uuid
 {
-    friend inline bool operator < (const Uuid& u1, const Uuid& u2);
+    PDAL_DLL friend inline bool operator < (const Uuid& u1, const Uuid& u2);
 public:
     Uuid()
-        { clear(); }
+        {}
     Uuid(const char *c)
         { unpack(c); }
     Uuid(const std::string& s)
         { parse(s); }
 
     void clear()
-        { memset(&m_data, 0, sizeof(m_data)); }
-
+        { m_data.clear(); }
     void unpack(const char *c)
     {
         BeExtractor e(c, 10);
@@ -199,23 +205,23 @@ private:
     uuid m_data;
 };
 
-inline bool operator == (const Uuid& u1, const Uuid& u2)
+PDAL_DLL inline bool operator == (const Uuid& u1, const Uuid& u2)
 {
     return !(u1 < u2) && !(u2 < u1);
 }
 
-inline bool operator < (const Uuid& u1, const Uuid& u2)
+PDAL_DLL inline bool operator < (const Uuid& u1, const Uuid& u2)
 {
     return u1.m_data < u2.m_data;
 }
 
-inline std::ostream& operator << (std::ostream& out, const Uuid& u)
+PDAL_DLL inline std::ostream& operator << (std::ostream& out, const Uuid& u)
 {
     out << u.toString();
     return out;
 }
 
-inline std::istream& operator >> (std::istream& in, Uuid& u)
+PDAL_DLL inline std::istream& operator >> (std::istream& in, Uuid& u)
 {
     std::string s;
     in >> s;
